@@ -1,6 +1,6 @@
 /*
 ******************************************************************
-Copyright (c) 2001-2013, Jeff Martin, Tim Bacon
+Copyright (c) 2001-2014, Jeff Martin, Tim Bacon
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -512,11 +512,11 @@ public class DifferenceEngine implements DifferenceConstants {
         throws DifferenceFoundException {
         if (control != null) {
             controlTracker.visited(control);
-            compare(control.getNodeName(), null, control, null,
+            compare(getQName(control), null, control, null,
                     listener, CHILD_NODE_NOT_FOUND, controlTracker, null);
         } else {
             testTracker.visited(test);
-            compare(null, test.getNodeName(), null, test, listener,
+            compare(null, getQName(test), null, test, listener,
                     CHILD_NODE_NOT_FOUND, null, testTracker);
         }
     }
@@ -623,8 +623,10 @@ public class DifferenceEngine implements DifferenceConstants {
                     }
                 } else {
                     controlTracker.clearTrackedAttribute();
+                    controlTracker.visited(nextAttr);
                     testTracker.clearTrackedAttribute();
-                    compare(attrName, null, control, test, listener,
+                    compare(getQName(nextAttr, isNamespacedAttr), null,
+                            control, test, listener,
                             ATTR_NAME_NOT_FOUND);
                 }
             }
@@ -638,9 +640,9 @@ public class DifferenceEngine implements DifferenceConstants {
             } else {
                 controlTracker.clearTrackedAttribute();
                 testTracker.clearTrackedAttribute();
+                testTracker.visited(nextAttr);
                 compare(null,
-                        getUnNamespacedNodeName(nextAttr,
-                                                isNamespaced(nextAttr)),
+                        getQName(nextAttr),
                         control, test, listener, ATTR_NAME_NOT_FOUND);
             }
         }
@@ -660,6 +662,16 @@ public class DifferenceEngine implements DifferenceConstants {
         return aNode.getNodeName();
     }
 
+    private String getQName(Node aNode) {
+        return getQName(aNode, isNamespaced(aNode));
+    }
+
+    private String getQName(Node aNode, boolean isNamespacedNode) {
+        if (isNamespacedNode) {
+            return "{" + aNode.getNamespaceURI() + "}" + aNode.getLocalName();
+        }
+        return aNode.getNodeName();
+    }
 
     /**
      * @param attribute
