@@ -168,4 +168,9 @@ public interface XMLConstants {
      */
     public static final String W3C_XML_SCHEMA_INSTANCE_TYPE_ATTR
         = "type";
+
+    /**
+     * ""
+     */
+    String NULL_NS_URI = "";
 }
